Assignment class

Assignment: x = expr

Inheritance

Constructors

Assignment(Token token, Identifier name, Expression value)

Properties

hashCode → int
The hash code for this object.
no setterinherited
name → Identifier
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
token → Token
final
value → Expression
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
tokenLiteral() → String
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited