ElvisExpr class

Elvis expression: expr ?: default

Inheritance

Constructors

ElvisExpr(Token token, Expression left, Expression defaultValue)

Properties

defaultValue → Expression
final
hashCode → int
The hash code for this object.
no setterinherited
left → Expression
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
token → Token
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
tokenLiteral() → String
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited