TernaryExpr class
Ternary expression: condition ? consequent : alternative
- Inheritance
-
- Object
- Node
- Expression
- TernaryExpr
Constructors
- TernaryExpr(Token token, Expression condition, Expression consequent, Expression alternative)
Properties
- alternative → Expression
-
final
- condition → Expression
-
final
- consequent → Expression
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- token → Token
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
tokenLiteral(
) → String -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited